ARTES
=====

**Atmospheric Radiative Transfer for Exoplanet Science**

.. image:: https://readthedocs.org/projects/artes/badge/?version=latest
    :target: http://artes.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/badge/License-GPLv3-blue.svg
    :target: https://github.com/tomasstolker/ARTES/blob/master/LICENSE

.. image:: http://img.shields.io/badge/arXiv-1706.09427-orange.svg?style=flat
    :target: http://arxiv.org/abs/1706.09427

ARTES is a 3D Monte Carlo radiative transfer code specifically designed for (polarized) scattered light simulations of planetary atmospheres. Computations of both reflected stellar light and thermal emission from the planet are possible for an arbitrary atmospheric structure and distribution of opacity sources. Multiple scattering, absorption, and polarization are fully treated and the output includes an image, spectrum, or phase curve. Several tools are included to create opacities and scattering matrices for molecules and clouds.

Documentation
-------------

Documentation can be found at `http://artes.readthedocs.io <http://artes.readthedocs.io>`_, including installation instructions, a description of the requires input files, and several examples.

Attribution
-----------

Please cite `Stolker et al., 2017, A&A, 607, A42 <http://adsabs.harvard.edu/abs/2017A%26A...607A..42S>`_ whenever results from ARTES are used in a publication.

License
-------

Copyright 2018-2020 Tomas Stolker

ARTES is free software and distributed under the GNU General Public License v3.